Welcome, world!

![[puppy]] #no extension

![](puppy.jpg) #not the entire path

![](./static/images/Eden_bonne_etoile_commission_perseith.webp)
![[Eden_bonne_etoile_commission_perseith.webp]]

[[disambiguation]] # index testing